# doreah

A collection of useful tools used in my Python projects. Since it's intended for personal use, I can not offer any guarantee for API consistency, backwards compatibility or similar.


[Documentation](https://doreah.readthedocs.io)
